# Nebari Plugin MLflow AWS

[![PyPI - Version](https://img.shields.io/pypi/v/nebari-plugin-mlflow-chart.svg)](https://pypi.org/project/nebari-plugin-mlflow-chart)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/nebari-plugin-mlflow-chart.svg)](https://pypi.org/project/nebari-plugin-mlflow-chart)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install nebari-plugin-mlflow-aws
```

## License

`nebari-plugin-mlflow-aws` is distributed under the terms of the [Apache](./LICENSE.md) license.
